# -*- coding: utf-8 -*-

# from ltc_client.worker import StandardWorker, DefaultIdLogFilter, HostnameFilter
from ltc_client.api import Api, NameQuantityPair, Quantity, Unit, Log, Cluster
from ltc_client.helpers import Machine, Job, Material, decode, encode
from ltc_client.winding_api import WindingApi
from ltc_client.geometry_api import GeometryApi


__title__ = "TINARM - Node creation tool for TAE workers"
__version__ = "0.2.49"
__author__ = "Martin West, Chris Wallis"
__license__ = "MIT License"
__copyright__ = "Copyright 2025 Tin Arm Engineering Ltd."
